import { BizError } from "../../util/bizError";
import { getInterfaceByInterfaceName } from "./cronJob";

export async function getZdwrqysc() {
    let interfaceName = "重点污染企业生产";
    let {pollutingEnterprises, productionByPollutingEnterprises, pollutingType, pollutingEnterprisesTOP10, comparisonOfPollutionTypesIndex, industryTypePollutantEnterprise, pollutingCompaniesScatter, rangeData} = await getInterfaceByInterfaceName(interfaceName);
    
    if (JSON.stringify(pollutingEnterprises) === '{}') pollutingEnterprises = {numPollutingEnterprises:0};
    if (JSON.stringify(productionByPollutingEnterprises) === '{}') productionByPollutingEnterprises = {pollutingEnterprisesIndex:0};
    if (JSON.stringify(pollutingType) === '{}') pollutingType = {waterPollution:0, hazardousWaste:0, airPollution:0, soilPollution:0, otherHighlights:0};
    if (JSON.stringify(rangeData) === '{}') rangeData = {regionalScope:"", timeRange:""};

    if (!pollutingEnterprises) throw new BizError(`${interfaceName} 缺少参数 pollutingEnterprises` );
    if (!productionByPollutingEnterprises) throw new BizError(`${interfaceName} 缺少参数 productionByPollutingEnterprises` );
    if (!pollutingType) throw new BizError(`${interfaceName} 缺少参数 pollutingType` );
    if (!pollutingEnterprisesTOP10) throw new BizError(`${interfaceName} 缺少参数 pollutingEnterprisesTOP10` );
    if (!comparisonOfPollutionTypesIndex) throw new BizError(`${interfaceName} 缺少参数 comparisonOfPollutionTypesIndex` );
    if (!industryTypePollutantEnterprise) throw new BizError(`${interfaceName} 缺少参数 industryTypePollutantEnterprise` );
    if (!pollutingCompaniesScatter) throw new BizError(`${interfaceName} 缺少参数 pollutingCompaniesScatter` );
    if (!rangeData) throw new BizError(`${interfaceName} 缺少参数 rangeData` );

    //污染企业数据
    let pollutingInfo = {污染企业总数: pollutingEnterprises.numPollutingEnterprises};

    //污染企业生产数据
    let productionInfo = {污染企业生产指数: productionByPollutingEnterprises.pollutingEnterprisesIndex};

    //污染类型
    let {waterPollution, hazardousWaste, airPollution, soilPollution, otherHighlights} = pollutingType;
    let pollutingTypeInfo = {
        水污染: waterPollution,
        危险污染: hazardousWaste,
        大气污染: airPollution,
        土壤污染: soilPollution,
        其他重点: otherHighlights    
    };

    //污染企业TOP10
    let pollutingTop10 = {};
    pollutingEnterprisesTOP10.forEach( info => {
        let {companyName, value} = info;
        pollutingTop10[companyName] = value;
    })

    //各污染类型企业生产指数对比
    let pollutionTypeInfo;
    let numberOfPollutingCompaniesData = {};
    let productionIndexData = {};
    comparisonOfPollutionTypesIndex.forEach( info => {
        let {pollutionType, numberOfPollutingCompanies, productionIndex} = info;
        numberOfPollutingCompaniesData[pollutionType] = numberOfPollutingCompanies;
        productionIndexData[pollutionType] = productionIndex;
    })
    pollutionTypeInfo = {污染企业数: numberOfPollutingCompaniesData, 生产指数: productionIndexData};

    //各行业类型污染企业生产指数对比
    let industryTypeInfo;
    let numberOfPollutingData = {};
    let productionData = {};
    industryTypePollutantEnterprise.forEach( info => {
        let {industryType, numberOfPollutingCompanies, productionIndex} = info;
        numberOfPollutingData[industryType] = numberOfPollutingCompanies;
        productionData[industryType] = productionIndex;
    })
    industryTypeInfo = {污染企业数: numberOfPollutingData, 生产指数: productionData};

    //范围数据
    let {regionalScope, timeRange} = rangeData;
    let rangeInfo = {
        "区域范围": regionalScope,
        "时间范围": timeRange
    };

    return {pollutingInfo, productionInfo, pollutingTypeInfo, pollutionTypeInfo, pollutingTop10, industryTypeInfo, pollutingCompaniesScatter, rangeInfo}
}